summaryrefslogtreecommitdiff
path: root/extensions
diff options
context:
space:
mode:
Diffstat (limited to 'extensions')
-rw-r--r--extensions/source/inc/componentmodule.cxx18
-rw-r--r--extensions/source/inc/componentmodule.hxx4
2 files changed, 11 insertions, 11 deletions
diff --git a/extensions/source/inc/componentmodule.hxx b/extensions/source/inc/componentmodule.hxx
index 3268264b1267..6b4dadfe5ac9 100644
--- a/extensions/source/inc/componentmodule.hxx
+++ b/extensions/source/inc/componentmodule.hxx
@@ -143,7 +143,7 @@ typedef ::com::sun::star::uno::Reference< ::com::sun::star::lang::XSingleService
//=========================================================================
//= OModuleResourceClient
//=========================================================================
- /** base class for objects which uses any global module-specific ressources
+ /** base class for objects which uses any global module-specific resources
*/
class OModuleResourceClient
{
@@ -155,7 +155,7 @@ typedef ::com::sun::star::uno::Reference< ::com::sun::star::lang::XSingleService
//=========================================================================
//= ModuleRes
//=========================================================================
- /** specialized ResId, using the ressource manager provided by the global module
+ /** specialized ResId, using the resource manager provided by the global module
*/
class ModuleRes : public ::ResId
{
diff --git a/extensions/source/inc/componentmodule.cxx b/extensions/source/inc/componentmodule.cxx
index 6c0b9956c5cf..e60acbf283f2 100644
--- a/extensions/source/inc/componentmodule.cxx
+++ b/extensions/source/inc/componentmodule.cxx
@@ -55,7 +55,7 @@ namespace COMPMOD_NAMESPACE
*/
class OModuleImpl
{
- ResMgr* m_pRessources;
+ ResMgr* m_pResources;
sal_Bool m_bInitialized;
rtl::OString m_sFilePrefix;
@@ -64,14 +64,14 @@ namespace COMPMOD_NAMESPACE
OModuleImpl();
~OModuleImpl();
/// get the manager for the ressources of the module
ResMgr* getResManager();
void setResourceFilePrefix(const ::rtl::OString& _rPrefix) { m_sFilePrefix = _rPrefix; }
};
//-------------------------------------------------------------------------
OModuleImpl::OModuleImpl()
- :m_pRessources(NULL)
+ :m_pResources(NULL)
,m_bInitialized(sal_False)
{
}
@@ -79,27 +79,27 @@ namespace COMPMOD_NAMESPACE
//-------------------------------------------------------------------------
OModuleImpl::~OModuleImpl()
{
- if (m_pRessources)
- delete m_pRessources;
+ if (m_pResources)
+ delete m_pResources;
}
//-------------------------------------------------------------------------
ResMgr* OModuleImpl::getResManager()
{
// note that this method is not threadsafe, which counts for the whole class !
- if (!m_pRessources && !m_bInitialized)
+ if (!m_pResources && !m_bInitialized)
{
DBG_ASSERT(!m_sFilePrefix.isEmpty(), "OModuleImpl::getResManager: no resource file prefix!");
// create a manager with a fixed prefix
- m_pRessources = ResMgr::CreateResMgr(m_sFilePrefix.getStr());
- DBG_ASSERT(m_pRessources,
+ m_pResources = ResMgr::CreateResMgr(m_sFilePrefix.getStr());
+ DBG_ASSERT(m_pResources,
rtl::OStringBuffer("OModuleImpl::getResManager: could not create the resource manager (file name: ")
.append(m_sFilePrefix)
.append(")!").getStr());
m_bInitialized = sal_True;
}
- return m_pRessources;
+ return m_pResources;
}
//=========================================================================
@@ -64,14 +64,14 @@ namespace COMPMOD_NAMESPACE
OModuleImpl();
~OModuleImpl();
- /// get the manager for the ressources of the module
+ /// get the manager for the resources of the module
ResMgr* getResManager();
void setResourceFilePrefix(const ::rtl::OString& _rPrefix) { m_sFilePrefix = _rPrefix; }